@@ -1,16 +1,9 @@
 from cliff.show import ShowOne
 from cliff.command import Command
 
-from enough.common.host import host_factory
-from enough.cli import openstack
-
-
-def set_common_options(parser):
-    parser.add_argument('--driver', default='openstack')
-    o = parser.add_argument_group(title='OpenStack',
-                                  description='Only when --driver=openstack')
-    openstack.set_common_options(o)
-    return parser
+from enough import settings
+from enough.common import Enough
+from enough.common import options
 
 
 class Create(ShowOne):
@@ -19,13 +12,13 @@ class Create(ShowOne):
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument('name')
-        return set_common_options(parser)
+        return options.set_options(parser)
 
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        host = host_factory(**args)
-        r = host.create_or_update()
+        e = Enough(settings.CONFIG_DIR, settings.SHARE_DIR, **args)
+        r = e.host.create_or_update()
         columns = ('name', 'user', 'port', 'ip')
         data = (parsed_args.name, 'debian', r['port'], r['ipv4'])
         return (columns, data)
@@ -37,10 +30,10 @@ class Delete(Command):
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument('name', nargs='+')
-        return set_common_options(parser)
+        return options.set_options(parser)
 
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        host = host_factory(**args)
-        host.delete()
+        e = Enough(settings.CONFIG_DIR, settings.SHARE_DIR, **args)
+        e.host.delete()
