@@ -1,6 +1,7 @@
 import argparse
 from cliff.command import Command
 
+from enough import settings
 from enough.common import ansible_utils
 
 
@@ -15,5 +16,5 @@ class Playbook(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        playbook = ansible_utils.Playbook(**args)
-        playbook.run()
+        playbook = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
+        playbook.run_from_cli(**args)
