@@ -30,13 +30,13 @@ class Enough(object):
 
         self.dotenough = DotEnough(self.config_dir, self.args['domain'])
         self.ansible = ansible_utils.Ansible(self.config_dir, self.share_dir)
-        if self.args.get('driver', 'openstack'):
+        if self.args.get('driver') == 'openstack':
             if 'cloud' not in self.args:
                 self.args['cloud'] = self.ansible.get_global_variable('openstack_cloud')
         self.hosts = Hosts(self.config_dir)
         self.host = host_factory(self.config_dir, self.share_dir, **self.args)
         self.service = service_factory(self.config_dir, self.share_dir, **self.args)
-        if self.args.get('driver', 'openstack'):
+        if self.args.get('driver') == 'openstack':
             self.openstack = OpenStack(self.config_dir, **self.args)
             self.heat = Heat(self.config_dir, **self.args)
         self.playbook = ansible_utils.Playbook(self.config_dir, self.share_dir)
