@@ -173,6 +173,7 @@ class Stack(OpenStackBase):
 
         network = self.definition.get('internal_network', OpenStackBase.INTERNAL_NETWORK)
         o = OpenStack(self.config_dir, **self.args)
+        o.delete_security_group(name)
         o.network_delete_if_not_used(network)
 
     def delete(self):
@@ -397,6 +398,13 @@ class OpenStack(OpenStackBase):
     def run(self, *args):
         return self.o(*args)
 
+    def delete_security_group(self, name):
+        try:
+            self.o.security.group.delete(name)
+        except sh.ErrorReturnCode_1:
+            return False
+        return True
+
     def network_exists(self, name):
         network = self.o.network.list('--format=value', '-c', 'Name', '--name', name)
         return network.strip() == name
@@ -500,6 +508,31 @@ class OpenStack(OpenStackBase):
             count += 1
         return count
 
+    def volume_prune(self, days):
+        r = self.o.volume.snapshot.list(
+            '--format=json', '--long', '-c', 'Volume', '--limit', '5000')
+        volumes_with_snapshots = set([x["Volume"] for x in json.loads(r.stdout)])
+        r = self.o.volume.list('--format=json', '-c', 'Name', '--limit', '5000')
+        before = (datetime.datetime.today() - datetime.timedelta(days)).strftime('%Y-%m-%d')
+        info = {
+            'no_date_prefix': [],
+            'has_snapshots': [],
+            'deleted': [],
+            'recent': [],
+        }
+        for volume in set([x["Name"] for x in json.loads(r.stdout)]):
+            if re.match(r'^\d\d\d\d\-\d\d-\d\d-', volume):
+                if volume in volumes_with_snapshots:
+                    info['has_snapshots'].append(volume)
+                elif volume[:10] < before:
+                    self.o.volume.delete(volume)
+                    info['deleted'].append(volume)
+                else:
+                    info['recent'].append(volume)
+            else:
+                info['no_date_prefix'].append(volume)
+        return info
+
     @retry(OpenStackShutoff, tries=5)
     def server_wait_shutoff(self, host):
         status = self.o.server.show('--format=value', '-c=status', host)
