@@ -76,8 +76,8 @@ class Service(object):
         return list(hosts | openvpn_hosts)
 
     def hosts_with_internal_network(self, hosts):
-        networks = self.ansible.get_variable_hosts('encrypted_device', 'openstack_network', *hosts)
-        return [host for (host, network) in networks.items() if network == 'internal']
+        info = self.ansible.get_variable_hosts('encrypted_device', 'network_internal_only', *hosts)
+        return [host for (host, internal_only) in info.items() if internal_only == 'True']
 
     def service_from_host(self, host):
         found = None
