@@ -13,6 +13,7 @@ class InstallScript(Command):
 
     def get_parser(self, prog_name):
         parser = super(InstallScript, self).get_parser(prog_name)
+        parser.add_argument('--registry')
         parser.add_argument('--function', action='store_true')
         parser.add_argument('--no-version', action='store_true')
         parser.add_argument('path', nargs='?')
@@ -26,6 +27,10 @@ class InstallScript(Command):
             path = parsed_args.path
             function = parsed_args.function
         self.args = parsed_args
+        if parsed_args.registry:
+            self.registry = parsed_args.registry
+        else:
+            self.registry = 'enoughcommunity/'
         if parsed_args.no_version:
             self.version = ''
         else:
