@@ -1,4 +1,6 @@
+from icinga2api.exceptions import Icinga2ApiException
 from tests.icinga_helper import IcingaHelper
+import pytest
 
 testinfra_hosts = ['ansible://icinga-host']
 
@@ -6,8 +8,11 @@ testinfra_hosts = ['ansible://icinga-host']
 class TestChecks(IcingaHelper):
 
     def test_icinga_host(self):
-        r = self.get_client().objects.get('Host', 'bind-host')
+        objects = self.get_client().objects
+        r = objects.get('Host', 'bind-host')
         assert r['attrs']['name'] == 'bind-host'
+        with pytest.raises(Icinga2ApiException):
+            objects.get('Host', 'deleted-host')
 
     def test_icinga_service(self, host):
         #  r = self.get_client().objects.list('Service', joins=['host.name'])
