@@ -2,6 +2,7 @@ import os
 import pytest
 import shutil
 import textwrap
+import yaml
 
 from enough.common import Enough
 
@@ -75,7 +76,9 @@ def pytest_sessionstart(session):
                route_to_internal=False)
     (needs_vpn, hosts) = get_hosts(session, e)
     r = e.create_missings(hosts)
-    if len(r) > 0:
+    with open(f'{e.config_dir}/inventory/group_vars/all/domain.yml', 'r') as f:
+        data = yaml.safe_load(f)
+    if len(r) > 0 or data.get('domain') == domain:
         e.heat.create_test_subdomain('enough.community')
     if needs_vpn:
         if not e.vpn_has_credentials():
