@@ -20,3 +20,7 @@ class TestChecks(IcingaHelper):
 
     def test_icinga_ntp_time(self):
         assert self.is_service_ok('website-host!systemd-timesyncd is working')
+
+    def test_memory(self):
+        assert self.is_service_ok('icinga-host!memory')
+        assert self.is_service_ok('website-host!memory')
