@@ -2,7 +2,9 @@ import website
 import testinfra
 from tests.icinga_helper import IcingaHelper
 
-testinfra_hosts = ['ansible://icinga-host']
+testinfra_hosts = ['ansible://bind-host']
+
+IcingaHelper.icinga_host = 'bind-host'
 
 
 class TestChecks(IcingaHelper):
