@@ -1,6 +1,8 @@
 from tests.icinga_helper import IcingaHelper
 
-testinfra_hosts = ['icinga-host']
+testinfra_hosts = ['ansible://bind-host']
+
+IcingaHelper.icinga_host = 'bind-host'
 
 
 class TestChecks(IcingaHelper):
