@@ -340,3 +340,20 @@ def test_volume_resize(tmpdir):
         o = OpenStack(settings.CONFIG_DIR)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
+
+
+#
+# Host
+#
+@pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip integration test')
+def test_host_create_or_update(tmpdir, openstack_name):
+    try:
+        enough = create_enough(tmpdir, 'host')
+        enough.set_args(name='new-host')
+        info = enough.host.create_or_update()
+        assert 'ipv4' in info
+    finally:
+        o = OpenStack(settings.CONFIG_DIR)
+        # comment out the following line to re-use the content of the regions and save time
+        o.destroy_everything(None)
