@@ -1,3 +1,4 @@
+import datetime
 import os
 import pytest
 import requests_mock as requests_mock_module
@@ -122,6 +123,38 @@ def test_backup_create_with_name(openstack_name, caplog):
     assert o.backup_prune(0) == 0
 
 
+@pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip integration test')
+def test_volume_prune(openstack_name, caplog):
+    o = OpenStack(settings.CONFIG_DIR)
+
+    volume_precious = openstack_name
+    o.o.volume.create('--size=1', volume_precious)
+    days = 2
+
+    old = days + 1
+    old_date = (datetime.datetime.today() - datetime.timedelta(old)).strftime('%Y-%m-%d')
+
+    old_volume_with_snapshot = f'{old_date}-old-with-snapshot-{openstack_name}'
+    o.o.volume.create('--size=1', old_volume_with_snapshot)
+    old_volume_snapshot = f'snapshot-{openstack_name}'
+    o.o.volume.snapshot.create('--volume', old_volume_with_snapshot, old_volume_snapshot)
+
+    old_volume = f'{old_date}-old-{openstack_name}'
+    o.o.volume.create('--size=1', old_volume)
+
+    recent = days - 1
+    recent_date = (datetime.datetime.today() - datetime.timedelta(recent)).strftime('%Y-%m-%d')
+
+    recent_volume = f'{recent_date}-{openstack_name}'
+    o.o.volume.create('--size=1', recent_volume)
+
+    assert o.volume_prune(days) == {'deleted': [old_volume],
+                                    'has_snapshots': [old_volume_with_snapshot],
+                                    'no_date_prefix': [volume_precious],
+                                    'recent': [recent_volume]}
+
+
 @pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
                     reason='skip integration test')
 def test_backup_create_no_names(openstack_name, caplog):
@@ -229,3 +262,12 @@ def test_openstack_volume_resize_no_volume(openstack_name):
 
     with pytest.raises(openstack.OpenStackVolumeResizeMissing):
         o.volume_resize(openstack_name, openstack_name, 1)
+
+
+@pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip integration test')
+def test_openstack_security_group(openstack_name):
+    o = OpenStack(settings.CONFIG_DIR)
+    o.o.security.group.create(openstack_name)
+    assert o.delete_security_group(openstack_name) is True
+    assert o.delete_security_group(openstack_name) is False
