@@ -34,7 +34,7 @@ clouds:
   production:
     auth: &os_auth
       auth_url: "$OS_AUTH_URL"
-      project_name: "${OS_PROJECT_NAME:-OS_TENANT_NAME}"
+      project_name: "${OS_PROJECT_NAME:-$OS_TENANT_NAME}"
       project_id: "${OS_PROJECT_ID:-$OS_TENANT_ID}"
       user_domain_name: "$OS_USER_DOMAIN_NAME"
       username: "$OS_USERNAME"
@@ -126,6 +126,12 @@ function run_tests() {
         args="--workdir /opt"
     else
         args="--volume ${d}:${d} --workdir ${d} --volume $HOME/.enough:$HOME/.enough --volume $HOME/.ansible:$HOME/.ansible -e HOME=$HOME"
+        # handle git worktree
+        git_dir="$(git rev-parse --absolute-git-dir)"
+        if [ "${git_dir}" != "${d}/.git" ]; then
+            git_common_dir="$(git rev-parse --git-common-dir)"
+            args="$args --volume ${git_common_dir}:${git_common_dir}"
+        fi
     fi
     docker run --rm --device=/dev/net/tun --name $name --user "${USER:-root}" -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN $skip --cap-add=NET_ADMIN $args --volume /var/run/docker.sock:/var/run/docker.sock $name "${@:-tox}"
 }
